# django-admin-honeypot

django-admin-honeypot is a fake Django admin login screen to log and notify
admins of attempted unauthorized access. This app was inspired by discussion
in and around Paul McMillan's security talk at DjangoCon 2011.

* **Author**: [Derek Payton](http://dmpayton.com)
* **Version**: 0.2.5
* **License**: MIT

[![Build Status](https://secure.travis-ci.org/dmpayton/django-admin-honeypot.png)](http://travis-ci.org/dmpayton/django-admin-honeypot)

## Documentation

http://django-admin-honeypot.readthedocs.org

### tl;dr

```
pip install django-admin-honeypot
```

* Add `admin_honeypot` to `INSTALLED_APPS`
* Update your urls.py:

    ```
    urlpatterns = patterns(''
        ...
        url(r'^admin/', include('admin_honeypot.urls')),
        url(r'^secret/', include(admin.site.urls)),
    )
    ```
